//
//  DetailViewController.swift
//  Aufgabenliste
//
//  Created by Holger Hinzberg on 19.11.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//

import UIKit

class DetailViewController: UIViewController
{
    @IBOutlet var titelTextfeld: UITextField!
    @IBOutlet var beschreibungTextfeld: UITextField!
    @IBOutlet var prioritaetLabel: UILabel!
    @IBOutlet var prioritaetSchieberegler: UISlider!
    
    var tabellenUebersicht:TabellenViewController?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        // Den Platzhaltertext entfernen
        self.prioritaetLabel.text = ""
        
        // Das Enum Dringlichkeit hat drei verschiedene Werte
        self.prioritaetSchieberegler.minimumValue = 1
        self.prioritaetSchieberegler.maximumValue = 3
        self.prioritaetSchieberegler.value = 1
        
        let prioritaet = lesePrioritaet()
        self.setzePrioritaet(prioritaet: prioritaet)
        
        // Wenn es eine gewählte Aufgabe gibt, müssen die
        // Eigenschaften des Objekts angezeigt werden
        if let aufgabe = self.tabellenUebersicht?.gewählteAufgabe
        {
            self.titelTextfeld.text = aufgabe.Titel
            self.beschreibungTextfeld.text = aufgabe.Beschreibung
            self.setzePrioritaet(prioritaet: aufgabe.Prioritaet)
        }
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
    }
    
    @IBAction func prioritaetSchiebereglerBewegt(_ sender: Any)
    {
        if let regler = sender as? UISlider
        {
            switch Int(regler.value)
            {
            case 1:
                self.prioritaetLabel.text = "Unwichtig"
            case 2:
                self.prioritaetLabel.text = "Wichtig"
            case 3:
                self.prioritaetLabel.text = "Sehr wichtig"
            default:
                self.prioritaetLabel.text = "Unbekannt"
            }
        }
    }
    
    func setzePrioritaet(prioritaet:Dringlichkeit)
    {
        switch prioritaet
        {
        case .Unwichtig:
            self.prioritaetSchieberegler.value = 1
            self.prioritaetLabel.text = "Unwichtig"
        case .Wichtig:
            self.prioritaetSchieberegler.value = 2
            self.prioritaetLabel.text = "Wichtig"
        case .SehrWichtig:
            self.prioritaetSchieberegler.value = 3
            self.prioritaetLabel.text = "Sehr Wichtig"
        }
    }
    
    func lesePrioritaet() -> Dringlichkeit
    {
        switch Int(self.prioritaetSchieberegler.value)
        {
        case 2:
            return .Wichtig
        case 3:
            return .SehrWichtig
        default:
            break
        }
        return .Unwichtig
    }
    
    @IBAction func speichernButtonBeruehrt(_ sender: Any)
    {
        if let aufgabe = self.tabellenUebersicht?.gewählteAufgabe
        {
            // Die bestehende Aufgabe ändern
            aufgabe.Titel = self.titelTextfeld.text!
            aufgabe.Beschreibung = self.beschreibungTextfeld.text!
            aufgabe.Prioritaet = self.lesePrioritaet()
            
            // Die Tabelle aktualisieren
            self.tabellenUebersicht?.aktualisieren()
        }
        else
        {
            // Eine neue Aufgabe erzeugen
            let aufgabe = Aufgabe()
            aufgabe.Titel = self.titelTextfeld.text!
            aufgabe.Beschreibung = self.beschreibungTextfeld.text!
            aufgabe.Prioritaet = self.lesePrioritaet()
            
            tabellenUebersicht?.aufgabeEinfuegen(aufgabe: aufgabe)
        }
        
        // Die aktuelle Szene beenden und
        // in der Navigation wiede eine Szene zurückgehen
        self.navigationController?.popViewController(animated: true)
    }
}
